@@ -237,21 +237,22 @@ def normalize_weights(graph: dict) -> dict:
 
 
 def normalize_positional_embeddings(embeddings: dict):
-    minn = 1
-    maxx = max(embeddings.values())
-    for node, position in embeddings.items():
-        embeddings[node] = (position - minn) / (maxx - minn)
+    if (len(embeddings)>0):
+        minn = 1
+        maxx = max(embeddings.values())
+        for node, position in embeddings.items():
+            embeddings[node] = (position - minn) / (maxx - minn)
 
 
 if __name__ == '__main__':
     nova_dataset = log_datasets.datasets.NovaDataset("../../data")
     nova_dataset.initialize_dataset()
-    networkx_graphs = nova_dataset.create_networkx_graphs(window_type="sliding", window_size=60000, window_slide=3000,
-                                                          test_id=2, include_last=True, include_all_event_ids=False,
-                                                          include_positional_embeddings=True)
+    # networkx_graphs = nova_dataset.create_networkx_graphs(window_type="sliding", window_size=60000, window_slide=3000,
+    #                                                       test_id=2, include_last=True, include_all_event_ids=False,
+    #                                                       include_positional_embeddings=True)
 
-    for graph in networkx_graphs:
-        print(graph.nodes.data(), graph.edges.data())
+    # for graph in networkx_graphs:
+    #     print(graph.nodes.data(), graph.edges.data())
     # graph_dicts = nova_dataset.create_graphs(window_type="sliding", window_size=60000, window_slide=3000, test_id=1,
     #                                          include_last=True, include_all_event_ids=True)
     # for graph_dict in graph_dicts:
